Hi Linus,

On 11/09/2024 06:57, Linus Lüssing wrote:
[...]
diff --git a/net/batman-adv/types.h b/net/batman-adv/types.h
index 00840d5784fe..fe0b9b229bff 100644
--- a/net/batman-adv/types.h
+++ b/net/batman-adv/types.h
@@ -1231,8 +1231,11 @@ struct batadv_priv_dat {
        /** @addr: node DAT address */
        batadv_dat_addr_t addr;
- /** @hash: hashtable representing the local ARP cache */
-       struct batadv_hashtable *hash;
+       /** @cache_hash: hashtable representing the local ARP cache */
+       struct batadv_hashtable *cache_hash;
+
+       /** @dht_hash: hashtable representing the local DAT DHT */
+       struct batadv_hashtable *dht_hash;

I haven't followed previous discussions, therefore my question may just sound redundant, but if "cache_hash" is for ARP what is the "DAT DHT"? (the A in DAT stands for ARP).

Moreover, it seems with this approach you are converting the DAT concept into something "type specific" - am I wrong?

Is it truly required just to have a different timeout?
Wouldn't a mark on entries be enough to instruct the subsystem about what timeout value to use?

Cheers,

/** @work: work queue callback item for cache purging */
        struct delayed_work work;

--
Antonio Quartulli

Reply via email to